Module waker

Module waker 

Helper waker proxy type.

Structs

WakerProxy
When reading the stream, a poll_ready is executed to ensure that all pending write op including heartbeat is completed. Therefore, we need to wake the task on which stream is polled in poll_ready (and poll_flush). WakerProxy is a waker dispatcher. It will dispatch a wake op to both wakers (rx & tx), such that both stream task and sink task can be waken and no starvation will occur.