Helper waker proxy type.
Structs
- Waker
Proxy - When reading the stream, a
poll_readyis executed to ensure that all pending write op including heartbeat is completed. Therefore, we need to wake the task on which stream is polled inpoll_ready(andpoll_flush).WakerProxyis a waker dispatcher. It will dispatch a wake op to both wakers (rx & tx), such that both stream task and sink task can be waken and no starvation will occur.